pub trait Party {
type Input: Send;
type Output: Debug + Send;
// Required method
fn run(
&mut self,
id: usize,
n_parties: usize,
input: &Self::Input,
channels: &mut Channels,
timings: &mut Timings,
) -> Self::Output;
// Provided method
fn get_name(&self, id: usize) -> String { ... }
}Expand description
A Party that takes part in a protocol. The party will receive a unique id when it is running the protocol, as well as
communication channels to and from all the other parties. A party keeps track of its own stats.
Required Associated Types
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".